@@ -5,6 +5,8 @@
 
 #include "types.h"
 
+namespace rgl {
+
 //
 // CLASS
 //   VertexArray
@@ -72,4 +74,6 @@ private:
   float* arrayptr;
 };
 
+} // namespace rgl
+
 #endif // RENDER_H
